/*
 * Initializes the page
 */
AJS.toInit( function() {
  
 loadConfiguration();
 
});

/*
 * Loads the configuration from the backend
 */
function loadConfiguration() {
  AJS.$.ajax({
      url: AJS.contextPath() + "/rest/samlsso-toolbox/1.0/users",
      dataType: "json",
      type: "get",
      success: function(users) {
          reinitializeTable(users)
      },
      error: function() {
          AJS.flag({
              type: 'error',
              title: 'Could not load users',
              body: 'This should not happen. Please check the server logs.'
          });
      }
  });
}

function createLozenge(user) {
    if(user.isSAMLCreated) {
        return "<span class='aui-lozenge aui-lozenge-success'>YES</span>";
    }
    else {
        return "<span class='aui-lozenge aui-lozenge-error'>NO</span>";
    }
}

// Url Mapping entries
function reinitializeTable(users) {
    var userTableBody = AJS.$('#user-table-body');
    userTableBody.html("");
    users.forEach(function(user) {
        var newTableEntry = AJS.$("<tr/>");
        userTableBody.append(newTableEntry);
        newTableEntry.append(AJS.$("<td>" + user.userid + "</td>"));
        newTableEntry.append(AJS.$("<td>" + createLozenge(user) + "</td>"));

        if(!user.isAdmin) {
            if(user.passwordAlreadyCleared) {
                newTableEntry.append(AJS.$("<td>Password cleared</td>"));
            }
            else {
                var actionsCell = AJS.$("<td/>");
                createActionLink('aui-iconfont-remove', 'Clear Password', actionsCell, function () {
                    console.log("resetting password for user ", user.userid);
                    AJS.$.ajax({
                        url: AJS.contextPath() + "/rest/samlsso-toolbox/1.0/users/" + user.userid + "/password",
                        dataType: "json",
                        type: "delete",
                        success: function(config) {
                            console.log("success");
                            AJS.flag({
                                type: 'success',
                                title: 'Password reset successful',
                                body: 'The password for the user was cleared or randomized.'
                            });
                            loadConfiguration();
                        },
                        error: function() {
                            AJS.flag({
                                type: 'error',
                                title: 'Password reset failed',
                                body: 'The password for the user was not cleared.'
                            });
                        }
                    });
                });
                if(!user.isSAMLCreated) {
                    createActionLink('aui-iconfont-group', 'Convert to SAML user', actionsCell, function () {
                        console.log("converting to saml for user ", user.userid);
                        AJS.$.ajax({
                            url: AJS.contextPath() + "/rest/samlsso-toolbox/1.0/users/" + user.userid + "/converttosamluser",
                            dataType: "json",
                            type: "put",
                            success: function (config) {
                                console.log("success");
                                AJS.flag({
                                    type: 'success',
                                    title: 'Success',
                                    body: 'The user is now a SAML user.'
                                });
                                loadConfiguration();
                            },
                            error: function () {
                                AJS.flag({
                                    type: 'error',
                                    title: 'Error',
                                    body: 'Converting to SAML user failed.'
                                });
                            }
                        });
                    });
                }
                newTableEntry.append(actionsCell);
            }
        }
        else {
            newTableEntry.append(AJS.$("<td>Not available (admin user).</td>"));
        }
    });
    if (users.length === 0) {
        userTableBody.append(AJS.$("<tr><td colspan='2'>No users found!</td></tr>"));
    }
}

function createActionLink (iconId, text, parent, callback) {
    var $newAction;
    if (typeof callback === "string") {
        $newAction = AJS.$("<a href='" + callback + "' target='_blank'/>");
    } else {
        $newAction = AJS.$("<a />");
        $newAction.click(callback);
    }
    $newAction.append(AJS.$("<p><span class='aui-icon aui-icon-small " + iconId + "'>" + text + "</span> " + text + "</p>"));
    parent.append($newAction);
}